calibrate_pixel_size: Calibrate the pixel size using a test image
Description
In order to calculate absolute densities from pixel sizes, the size of the
field captured by an operating microscope must be determined. This function
allows the user to select an image of a ruler captured under a microscope,
before automatically determining the scale.