Learn R Programming

vmeasur (version 0.1.4)

select_roi: Select a ROI from a video file

Description

This function provides a graphical tool to walk the user through selecting a ROI from an AVI video.

Usage

select_roi()

Arguments

Value

Saves an annotated AVI and CSV file in the same directory as the video. Will also output and copy the parameters used to create the video.

Examples

Run this code
# NOT RUN {
# }
# NOT RUN {
   select_roi()
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab