Apply a threshold to a single frame
threshold_vessel(file_path = tk_file.choose(), threshold, min_area = 100)path to the file to be used. If left blank, the user will be prompted to make a selection
The threshold to use
Minimum area to recognize as a vessel. Any smaller items will be ignored
a data frame containing the widths of the vessel in each row of the image, and if any rows were excluded due to overexposure