powered by
This function provides a graphical tool to walk the user through selecting a ROI from an AVI video.
select_roi()
Saves an annotated AVI and CSV file in the same directory as the video. Will also output and copy the parameters used to create the video.
# NOT RUN { # } # NOT RUN { select_roi() # } # NOT RUN { # }
Run the code above in your browser using DataLab